@@ -11,9 +11,15 @@ from drf_yasg import openapi
 from drf_yasg.views import get_schema_view
 
 from ...core.permissions import is_staff
+from ...core.apps.users.serializers import UserSerializer
+from ...core.apps.groups.models import Group
+from ...core.apps.groups.serializers import GroupSerializer
+from ...core.apps.services.models import Service
+from ...core.apps.services.serializers import ServiceSerializer
+
 from ..views import local_space_available, CURRENT_DIR, logger
 
-from django_sso_app import dist_name, __version__
+from django_sso_app import dist_name, __version__, app_settings
 
 logger = logging.getLogger('django_sso_app.backend.api')
 
@@ -29,12 +35,25 @@ class StatsView(APIView):
         try:
             health_status = 'green'
 
+            user_types = Group.objects.filter(name__in=app_settings.USER_TYPES)
+            services = Service.objects.filter(is_public=True)
+
+            context = {
+                'request': request
+            }
+
             data = {
                 'app_name': dist_name,
                 'deployment_environment': settings.DEPLOYMENT_ENV,
                 'revision': settings.REPOSITORY_REV,
                 'version': __version__,
 
+                'user': UserSerializer(request.user, context=context).data if request.user.is_authenticated else None,
+
+                'user_types': GroupSerializer(user_types, many=True, context=context).data,
+
+                'services': ServiceSerializer(services, many=True, context=context).data,
+
                 'meta': str(request.META.items())
             }
 
